* migstat09_stata.zip: migstat09.do [Korrekturen 06.11.2012: Zeile 522, 527, 1660, 1682]
* =============================================================================

* Stata/MP 12.1 for Windows

clear
capture log close
set more off
set memory 800m
set dp comma
set linesize 250

* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */ 
cd '<Arbeitsverzeichnis>'


log using migstat2009.log, replace text

/* ===========================================================================
Programmname: migstat09.do
   STATA-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2009
                                                                      
Programmautor/en                                                    
   SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt; 
      Referat F 204 Migration und Integration, Wohnen)
  Anpassungen an Scientific Use File Mikrozensus 2009: Delia Jaeger,
     Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck
   Dieses Programm dient der Replikation des Migrationsstatus, Variable EF2001,
   und der Staatsangehoerigkeit zum Migrationsstatus (EF2008) im Scientific Use
   File (SUF) des Mikrozensus 2009.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus des 
   Statistischen Bundesamtes und wurden an Recodierungen des SUF angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus 
   (MIGS und MIGS2009) ist zu beachten, dass aus Gruenden des Datenschutzes 
   Angaben zur zweiten Staatsangehoerigkeit (EF354, EF362, EF370) nur 
   rudimentaer vorhanden sind. Des Weiteren sind die zur Konstruktion von MIGS
   verwendeten Variablen
     EF369 1. Staatsangehoerigkeit (der Person),
     EF353 1. ausl. Staatsangehoerigk.: Mutter und
     EF362 1. ausl. Staatsangehoerigk.: Vater 
  unterschiedlich codiert. Die Replikation ist deshalb nur mit Abweichungen 
  moeglich. Da die Variable EF2008 im SUF enthalten ist, wird keine 
  Harmonisierung der Ausgangsvariablen EF369, EF353 und EF362 vorgenommen.

Weiterfuehrende Programmbeschreibung:
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des 
   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files 2005-2009. 
   GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.
   URL: http://www.gesis.org/fileadmin/upload/forschung/
        publikationen/gesis_reihen/gesis_methodenberichte/2012/
        TechnicalReport_2012-08.pdf

Download dieser Datei:
   http://www.gesis.org/missy/studie/klassifikationen/
   konzepte-und-definitionen/migrationshintergrund/migstat09_stata.zip

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu 
   einer definitorischen Abgrenzung - S. 398-407 in: Statistisches Bundesamt, 
   2011: Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 
   2009. Fachserie 1 Reihe 2.2. Wiesbaden.
   URL: https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob=
   publicationFile; letzter Zugriff: 24.07.2012.

Programmstruktur:
   0. Datenvorbereitung
   1. Grundtypisierung des Migationshintergrundes
   2. Identifikation von 3-Generationen-Haushalten
   3. Endtypisierung der Grosseltern
   4. Endtypisierung der Eltern
   5. Endtypisierung Befragte
   6. Umsetzung von Zeitreihenkompatibilitaet
   7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

Programmstatus:
  Getestet mit Stata/MP 12.1 for Windows und dem Scientific Use File 
  Mikrozensus 2009 
  Stand: Juli 2012 
============================================================================ */

* Scientific Use File Mikrozensus 2009 - Variablenauszug
*    Lokalen Dateinamen inkl. Verzeichnis in <> eintragen
use EF1   EF3   EF4   EF5a  EF5b  EF8   EF9   EF12  EF30  EF31  EF37 ///
    EF44  EF46  EF47  EF49  EF50  EF51  EF52  EF53  EF54  EF55 ///
    EF349 EF350 EF351 EF352 EF353 EF354 EF355 EF356 EF382 ///
    EF357 EF358 EF359 EF360 EF361 EF362 EF363 EF364 EF365 ///
    EF366 EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374 ///
    EF663 EF952 EF2001-EF2011 ///
  using <mz2009.dta>, replace

* Gross- => Kleinschreibung
renpfix EF ef


* Variablenauszug speichern
save temp_mz09.dta, replace

* Value Label um Code ergaenzen
numlabel, add mask("[#] ") force

* ====================================================================
* 0. DATENVORBEREITUNG

* Satznummer im Ausgangsfile
gen ID = _n
label var ID "Satznummer Ausgangsfile"

* Neue Haushaltsnr. (V4) bilden, um extra Programme fuer Jahresbestand
*      (EF5b=0) und Jahresueberhang (EF5b=1) zu vermeiden
gen v4 = ef4 * 100 + ef5b * 10 + ef12
label var v4 "HHNR EF4 * 100 + EF5b*10 + EF12"

* Neue PERS.Nr.
gen v5 = ef5a
label var v5 "PERS.NR im HH (ex EF5a)"


/* ============================================================================
Korrektur (X) in EF52 und EF53; siehe 2. Identifikation 3-Gen-HH
   EF3 EF4   V4 EF5a EF5b EF12 V5 EF44 EF46 EF52 EF53 
  2637  12 1202   1    0    2   1  34    2    1 X  2  ! Mutter - Kind vertauscht
  2637  12 1202   2    0    2   2   0    2    1    1

 11354  20 2002   1    0    2   1  24    2    1 X  2  ! Mutter - Kind vertauscht
 11354  20 2002   2    0    2   2   4    2    1    1

 25858   7  704   1    0    4   1  33    2    1 X  2  | Mutter - Kind vertauscht
 25858   7  704   2    0    4   2   6    2    1    1
 */
 
* Originalvariablen sichern
gen ef52_O = ef52
gen ef53_O = ef53

replace ef52=8  if (ef3==2637 & ef4==12 & ef5b==0 & ef12==2 & ef5a==1)
replace ef53=-5 if (ef3==2637 & ef4==12 & ef5b==0 & ef12==2 & ef5a==1)

replace ef52=8  if (ef3==11354 & ef4==20 & ef5b==0 & ef12==2 & ef5a==1)
replace ef53=-5 if (ef3==11354 & ef4==20 & ef5b==0 & ef12==2 & ef5a==1)

replace ef52=8  if (ef3==25858 & ef4==7 & ef5b==0 & ef12==4 & ef5a==1)
replace ef53=-5 if (ef3==25858 & ef4==7 & ef5b==0 & ef12==4 & ef5a==1)



* --------------------------------------------------------------------
/* Harmonisierung der 1. Staatsangehoerigkeiten

Vergleichbare Codes bei Harmonisierung der Staatsangehoerigkeiten 
      EF369 1. Staatsangehoerigkeit
      EF374 Staatsangehoerigk.: durch Geburt/Einbuergerung/Spaetaussiedler

      EF353 1. ausl. Staatsangehoerigk.: Mutter
      EF382 Staatsangehoerigk.: Mutter, vor Einbuergerung/Zuzug als Spaetaussiedlerin

      EF361 1. ausl. Staatsangehoerigk.: Vater
      EF365 Staatsangehoerigk.: Vater, vor Einbuergerung/Zuzug als Spaetaussiedler

Diese Recodierung fuehrt allerdings zu einem erheblichen Informationsverlust. 
Die Recodierung wird daher nicht vorgenommen.

Des Weiteren koennen veroeffentlichte Ergebnisse aufgrund fehlender differenzierter 
Angaben zur 2. Staatsangehoerigkeit nur naeherungsweise repliziert werden. 
Deshalb werden die Zuweisungen
      sa2=ef370
      sa2me=ef354
      sa2ve=ef362
hier nicht verwendet (s. u. "deaktiviert").  
-------------------------------------------------------------------- */


* ============================================================================

* Ausgangssortierung: Bundesland (ef1), Auswahlbezirk (ef3), fortlfd. HH-Nr. 
*                     inkl. Jahresueberhang (v4), neue Pers.nr. im HH (v5)
sort ef1 ef3 v4 v5 

/* ====================================================================
1. Grundtypisierung des Migrationshintergrundes
   Es werden zunaechst nur die Angaben der Person selbst zur Typisierung 
   verwendet. Die erste Typisierung erfolgt nach Angaben zur 
   Staatsangehoerigkeit (deutsch / nicht-deutsch) und Geburtsland (Ausland /
   Inland).
   Zur Unterscheidung der Gruppe eingebuergerter Zuwanderer (MIG=31) nach 
   einem evtl. Status als Spaetaussiedler wird abschliessend geprueft, ob 
   der Ehegatte, der Vater oder die Mutter im Haushalt einen 
   Spaetaussiedlerstatus besitzt.
   Trifft dies zu, erfolgt eine Rekodierung (Plausibilisierung)
   von MIG=31 'zugewanderter eingebuergerter Auslaender' zu
   MIG=22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne 
   Einbuergerung)'.
*/

gen gebj=ef47
label var gebj "Geburtsjahr (EF47)"

gen brdborn=ef366
label var brdborn "Geburtsland: BRD (EF366)"
label def brdborn 1 "Ja, hier geboren" ///
                  8 "Nein, zugezogen" ///
                  9 "ohne Angabe"
label val brdborn brdborn

recode brdborn (1=0 "[0] kein Zuzug") ///
               (8=1 "[1] foreign born") ///
               (9=9 "[9] k.A.") ///
               (*=9), gen(zuzug)
label var zuzug "Zuzug ex BRDBorn, EF366"
label def zuzug 2 "Zuzug nach 6+ Mo im Ausland:= in D geboren", add modify
                 
gen jzuzug=ef367
replace jzuzug=1949 if (ef367==1949)  /* Zuzug vor 1950 */
replace jzuzug=9    if (ef367==9999)  /* o.A. zum Zuzugsjahr */
replace jzuzug=0    if (ef367==-5)    /* kein Zuzugsjahr sinnvoll */
label var jzuzug "Zuzugsjahr"
label def jzuzug 1949 "Zuzug vor 1950" ///
                    9 "o.A. zum Zuzugsjahr" ///  
                    0 "kein Zuzugsjahr sinnvoll"

replace zuzug=2  if (brdborn==1 & jzuzug>9) 
replace jzuzug=9 if (brdborn==8 & jzuzug<=9)

* Initialisierung
gen mig=.
gen ausl=.
gen sadopp=.
gen sa=.
gen sa1=.
gen sa2=.
gen sa3=.
gen spauss=.
gen eingeb=.
gen jeinb=.
gen sa_erw=.

* SA*: Staatsangehoerigkeit
* nur deutsche SA
replace ausl=0   if (ef368==1)
replace sadopp=0 if (ef368==1)
replace sa1=0    if (ef368==1)
replace sa2=.    if (ef368==1)

* deutsche und auslaendische SA .
replace ausl=0    if (ef368==2)
replace sadopp=1  if (ef368==2)
replace sa1=0     if (ef368==2)
replace sa2=ef369 if (ef368==2) 

* nur auslaendische SAs .
replace ausl=1    if (ef368==8)
replace sa1=ef369 if (ef368==8)
replace sadopp=0  if (ef368==8 & ef370!=1) 
replace sa2=.     if (ef368==8 & ef370!=1)
replace sa2=0     if (ef368==8 & (ef370==0 | ef370==-5))
replace sadopp=1  if (ef368==8 & ef370==1)
* DEAKTIVIERT: replace sa2=ef370 if (ef368==8 & ef370==1) 

label var sa1 "Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)"
label var sa2 "Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)"
label var sadopp "Doppelte Staatsangehoerigkeit (EF368-EF370)"
label var ausl "Auslaendische Staatsangehoerigkeit"
label def ausl   0 "nein" 1 "ja"
label def sadopp 0 "nein" 1 "ja"
label val ausl ausl
label val sadopp sadopp

* Spaetaussiedler ohne Einbuergerung 
replace spauss=1   if (ef372==2)
replace eingeb=0   if (ef372==2)
replace jeinb=.    if (ef372==2)
replace sa3=ef374  if (ef372==2)
recode  sa3 (-5=.) if (ef372==2)
replace sa2=ef369  if (ef372==2)
recode  sa2 (-5=.) if (ef372==2)

* Spaetaussiedler mit Einbuergerung
replace spauss=1     if (ef372==3)
replace eingeb=1     if (ef372==3)
replace jeinb=ef373  if (ef372==3)
recode  jeinb (-5=9) if (ef372==3)
replace sa3=ef374    if (ef372==3)
recode  sa3 (-5=.)   if (ef372==3)
replace sa2=ef369    if (ef372==3)
recode  sa2 (-5=.)   if (ef372==3)

* sonstige Einbuergerung 
replace spauss=0     if (ef372==4)
replace eingeb=1     if (ef372==4)
replace jeinb=ef373  if (ef372==4)
recode  jeinb (-5=9) if (ef372==4) 
replace sa3=ef374    if (ef372==4)
recode  sa3 (-5=.)   if (ef372==4)
replace sa2=ef369    if (ef372==4)
recode  sa2 (-5=.)   if (ef372==4)

* Deutsch durch Geburt
replace spauss=0   if (ef372==1)
replace eingeb=0   if (ef372==1)
replace jeinb=.    if (ef372==1)
replace sa2=ef369  if (ef372==1)
recode  sa2 (-5=.) if (ef372==1)

* keine deutsche Staatsangehoerigkeit
replace spauss=0 if (ausl==1) 
replace eingeb=0 if (ausl==1)
replace jeinb=.  if (ausl==1)
replace sa3=.    if (ausl==1)

label var spauss "Spaetaussiedler"
label var eingeb "Eingebuergert"
label var jeinb  "Einbuergerungsjahr"
label var sa3    "Staatsangeh. vor Einbuergerung/Zuzug als Spaetaussiedler"
label def spauss 0 "nein" 1 "ja"
label val spauss spauss
label def eingeb 0 "nein" 1 "ja"
label val eingeb eingeb

/* -------------------------------------------------------------------
Ueberblick zu nachfolgenden Zuweisungen
MIG: Migrationstypus
     1. Stelle: Migrationstyp:
                1=vertrieben
                2=als Deutsche/r bzw. Spaetaussiedler zugewandert
                3=eingebuergert
                4=Auslaender/in
     2. Stelle: Generation:
                1=im Ausland geboren
                2=in Deutschland geboren
Vorlaeufige Codes MIG
11=Vertriebene vor 1950
21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)
22=Ehegatte o. Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuerg.)
25=(Spaet-)Aussiedler (mit Einbuergerung)
29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr
31=zugewanderter eingebuergerter Auslaender
32=nicht zugewanderter eingebuergerter Auslaender
41=zugewanderter Auslaender
42=nicht zugewanderter Auslaender
77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler
99=fehlende/unvollstaendige Angaben
----------------------------------
SA_erw: Erweiterte aktuelle Staatsangehoerigkeit
        [Basis fuer MIGS Staatsangehoerigkeit: Migrationsstatus]
        gewonnen aus
          SA1 Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)
          SA2 Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
          SA3 Staatsangeh. vor Einbuerg./Zuzug als Spaetaussiedler
        nach folgenden Regeln:
SA_erw = 0   = deutsch (bei MIG=0, 11)
       = SA1 (bei Mig=41,42)
       = SA3 (bei Mig=21,25,29,31,32 und SA3<>.)
       = SA2 (bei MIG=21,25,29,31,32 und SA3=. und SA2<>.)
       = 99  (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder
              bei MIG=77,99)
         [System missings sind oben bezeichnet mit: "." ]
------------------------------------------------------------------- */

* A) im Ausland geboren
* A1) als Auslaender zugewandert
replace mig=41     if (brdborn==8 & ausl==1)
replace sa=sa1     if (brdborn==8 & ausl==1)
replace sa_erw=sa1 if (brdborn==8 & ausl==1)

* A2) Spaetaussiedler/in
*     SA_erw: SA vor Einbuergerung
*             wenn fehlt, 2. SA (Doppelstaatler)
*             ansonsten 'missing'
replace mig=25     if (brdborn==8 & spauss==1 & eingeb==1 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==1 & eingeb==1 & mig==25)
replace sa_erw=sa3 if (brdborn==8 & spauss==1 & eingeb==1 & mig==25)
replace sa_erw=sa2 if (brdborn==8 & spauss==1 & eingeb==1 & sa_erw==. & mig==25)
replace sa_erw=99  if (brdborn==8 & spauss==1 & eingeb==1 & sa_erw==. & mig==25)

* Spaetaussiedler ohne Einbuergerung
replace mig=21     if (brdborn==8 & spauss==1 & eingeb==0 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==1 & eingeb==0 & mig==21)
replace sa_erw=sa3 if (brdborn==8 & spauss==1 & eingeb==0  & mig==21)
replace sa_erw=sa2 if (brdborn==8 & spauss==1 & eingeb==0 & sa_erw==.  & mig==21)
replace sa_erw=99  if (brdborn==8 & spauss==1 & eingeb==0 & sa_erw==. & mig==21)

* kein Spaetaussiedler ... 
* A3) Eingebuergerte/r
replace mig=31     if (brdborn==8 & spauss==0 & eingeb==1 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==1 & mig==31)
replace sa_erw=sa3 if (brdborn==8 & spauss==0 & eingeb==1 & mig==31)
replace sa_erw=sa2 if (brdborn==8 & spauss==0 & eingeb==1 & sa_erw==. & mig==31)
replace sa_erw=99  if (brdborn==8 & spauss==0 & eingeb==1 & sa_erw==. & mig==31)

* ... Deutsche/r durch Geburt
* A4) Vertriebener vor 1950 
replace mig=11     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11)
replace sa_erw=sa1 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11)

* A5) Aussiedler-aequivalent 
replace mig=21     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & jzuzug<. & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & jzuzug<. & mig==21)
replace sa_erw=sa3 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & jzuzug<. & mig==21)
replace sa_erw=sa2 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & jzuzug<. & sa_erw==. & mig==21)
replace sa_erw=99  if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & jzuzug<. & sa_erw==. & mig==21)

* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann 
*                         Vertriebener oder Spaetaussiedler sein
* Annahme 1: wenn nach 1949 geboren, dann als Spaetaussiedler zugewandert
replace mig=21     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21)
replace sa_erw=sa3 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21)
replace sa_erw=sa2 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & sa_erw==. & mig==21)
replace sa_erw=99  if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & sa_erw==. & mig==21)
replace mig=21 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>=1911 & gebj<=1949 & mig==.)
replace sa=sa1 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>=1911 & gebj<=1949 & mig==21)
replace sa_erw=sa3 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>=1911 & gebj<=1949 & mig==21)
replace sa_erw=sa2 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>=1911 & gebj<=1949 & sa_erw==. & mig==21)
replace sa_erw=99  if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>=1911 & gebj<=1949 & sa_erw==. & mig==21)

* Annahme 2: Wenn vor 1949 geboren und keine auslaendaendische SA, dann Vertriebener 
replace mig=11     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & gebj<=1949 & sadopp==0 & sa1==0 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11)
replace sa_erw=sa1 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11)

* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 
replace mig=29     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==.)
replace sa=sa1     if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29)
replace sa_erw=sa3 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29)
replace sa_erw=sa2 if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & sa_erw==. & mig==29)
replace sa_erw=99  if (brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & sa_erw==. & mig==29)

* B) im Inland geboren: 
* B1) als Auslaender in D geboren 
replace mig=42     if (brdborn==1 & ausl==1 & mig==.)
replace sa=sa1     if (brdborn==1 & ausl==1 & mig==42)
replace sa_erw=sa1 if (brdborn==1 & ausl==1 & mig==42)

* B2) Spaetaussiedler/in, Fehler! 
replace mig=77     if (brdborn==1 & spauss==1 & mig==.)
replace sa=sa1     if (brdborn==1 & spauss==1 & mig==77)  
replace sa_erw=sa3 if (brdborn==1 & spauss==1 & mig==77)
replace sa_erw=sa2 if (brdborn==1 & spauss==1 & sa_erw==. & mig==77)
replace sa_erw=99  if (brdborn==1 & spauss==1 & sa_erw==. & mig==77)

* B3) Eingebuergerte/r 
replace mig=32     if (brdborn==1 & eingeb==1 & mig==.)
replace sa=sa1     if (brdborn==1 & eingeb==1 & mig==32)
replace sa_erw=sa3 if (brdborn==1 & eingeb==1 & mig==32)
replace sa_erw=sa2 if (brdborn==1 & eingeb==1 & sa_erw==. & mig==32)
replace sa_erw=99  if (brdborn==1 & eingeb==1 & sa_erw==. & mig==32)

* B4) in Deutschland geborener Deutscher 
replace mig=77     if (brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==.)
replace sa=sa1     if (brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77) 
replace sa_erw=sa3 if (brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77)
replace sa_erw=sa2 if (brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & sa_erw==. & mig==77)
replace sa_erw=sa1 if (brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & sa_erw==. & mig==77)

*   brdborn=9: keine Auskunft; kommt wohl nicht vor
replace mig=99     if (brdborn==9 & mig==.)
replace sa=sa1     if (brdborn==9 & mig==99)
replace sa_erw=sa3 if (brdborn==9 & mig==99)
replace sa_erw=sa2 if (brdborn==9 & sa_erw==. & mig==99)
replace sa_erw=sa1 if (brdborn==9 & sa_erw==. & mig==99)

label var sa "Aktuelle Staatsangehoerigkeit"
label var sa_erw "Erweiterte aktuelle Staatsangehoerigkeit"
label var mig "Migrationsstatus"
recode mig (.=99)
/* label def mig /// 
    0 "SYSMIS" ///
   11 "Vertriebene vor 1950" ///
   21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "zugewanderte/r Auslaender/in" ///
   42 "nicht zugewanderte/r Auslaender/in" ///
   77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "fehlende/unvollstaendige Angaben"
*/
   
gen sa_erw1 = sa_erw
label var sa_erw1 "Erw. Staatsangeh. vor Plausibilis."

* Zwischenspeicherung MIG vor Plausibilisierungen und vor VE/ME
save "temp_mig1.dta", replace

/* -------------------------------------------------------------------
Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31), dann pruefen, 
ob ggf. Spaetaussiedlerstatus vorliegt
a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29) 
b) Vater ist Spaetaussiedler (MIG[Vater]=21-29) 
c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29)
Nachfolgende Pruefungen der Gruppe der Zuwanderer mit Angaben zu einer 
Einbuergerung, ob ggf. ein Spaetaussiedlerstatus vorliegt, gehen von 
dieser Definition valider Spaetaussiedler (ex: 02Vorlauf.sas) aus:
  EF366 = 8 &               (Geburtsland nicht BRD)
  & (EF372 = 3 | EF372 = 2) (Besitz der deutschen Staatsangeh. 
                             als (Spaet-)Aussiedler mit oder
                             ohne Einbuergerung) 
  & JZuzug>1949             (Zuzugsjahr nach 1949)

Der in den einzelnen Programmschritten gebildete Migrationsstatus
(MIG) wird zur Kontrolle der jeweiligen Rekodierungen umbenannt.
Am Ende erhaelt die Typisierung wieder den Variablennamen MIG.
------------------------------------------------------------------- */

rename mig mig1
label var mig1 "Migrationsstatus vor Plausibilisierung a) Ehegatte"

* -------------------------------------------------------------------
* A) PLAUSIBILISIERUNG - EHEGATTE
gen vorl = (ef366==8 & (ef372==3 | ef372==2) & jzuzug>1949) 
label var vorl "Valide Spaetaussiedler - PERSON"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

* EHEGATTEN IM HAUSHALT
keep if ef50==1  // Ehegatte im Haushalt
keep  ef1 ef3 v4 ef5a ef50 mig1 vorl jzuzug ef366 ef372 // 06.11.2012 ex: keep  ef1 ef3 v4 ef5a ef50 mig vorl jzuzug ef366 ef372
rename ef5a   ef5_E
rename jzuzug jzuzug_E
rename ef366  ef366_E
rename ef372  ef372_E
rename mig1   mig_E // 06.11.2012 ex: rename mig   mig_E
rename vorl   vorl_E
sort ef1 ef3 v4 ef5_E ef50
save temp_E.dta, replace

* GESAMTFILE 
use temp.dta, clear
gen ef5_E = ef51 * (ef50==1)
label var ef5_E "Nr. des Ehepartners im Haushalt (ef51)"
* Sortierung fuer Zusammenspielen Ehegatten
sort ef1 ef3 ef4 ef5_E ef50

* Angaben der Ehegatten zusammenspielen 
merge m:m ef1 ef3 v4 ef5_E ef50 using temp_E.dta
* tab _merge ef50, miss 
drop _merge

* Sortierung des Ausgangsfiles
sort ef1 ef3 v4 v5

gen mig1a=mig1
replace mig1a=22 if (mig1==31    /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31) 
                   & jzuzug>10   /// und valides Zuzugsjahr 
                   & ef50==1     /// Ehegatte im Haushalt (ergaenzt) 
                   & (abs(jzuzug-jzuzug_E)<3) /// Diff +- 3 Jahre zum Zuzugsjahr des Ehegatten 
                   & vorl_E==1)               //  Ehegatte ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949 
* n=98 Aenderungen mig1a - mig1
				   
label var mig1a "Migrationsstatus nach Plausib a) Ehegatte"

* Pruefung und Rekodierung 
* tab mig1a mig1 if mig1a!=mig1

* ----------------------------------------------------------------------------
* B) PLAUSIBILISIERUNG - VATER
gen vnr = ef55 * (ef54==1)
label var vnr "Personennr. des Vaters (EF55)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if ef54==1
keep ef1 ef3 v4 vnr

* ==> Sortierung ... vnr
sort ef1 ef3 v4 vnr

rename vnr ef5a
gen v_kids=1
collapse (count) v_kids, by(ef1 ef3 v4 ef5a)
label var v_kids "Anzahl lediger Kinder eines Vaters"

save temp_V1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 ef5a

* Anzahl der Kinder den Vaetern zuspielen 
merge m:m ef1 ef3 v4 ef5a using temp_V1.dta
* tab _merge, miss
drop _merge

recode v_kids (1/99=1), gen(vater)
label var vater "Vater lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if (vater==1)
keep  ef1 ef3 v4 ef5a mig1a vorl jzuzug ef366 ef372 
rename ef5a   vnr
rename jzuzug jzuzug_V
rename ef366  ef366_V
rename ef372  ef372_V
rename mig1a  mig_V
rename vorl   vorl_V
sort ef1 ef3 v4 vnr
save temp_V1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V1.dta
* tab _merge ef54, miss
drop _merge
* tab mig_V vater

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 v4 ef5a

gen mig1b = mig1a
replace mig1b=22 if (mig1a==31  /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                 & jzuzug>10    /// und valides Zuzugsjahr
                 & ef54==1      /// Vater im Haushalt (ergaenzt)
                 & (abs(jzuzug-jzuzug_V)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr des Vaters
                 & vorl_V==1)   //  Vater ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949
* n=8  Rekodierungen MIG=31 -> MIG=22

* Pruefung und Rekodierung 
* tab mig1b mig1a if mig1b!=mig1a


* -------------------------------------------------------------------
* C) PLAUSIBILISIERUNG - MUTTER

gen mnr = ef53 if (ef52==1)
label var mnr "Personennr. der Mutter (ef53)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if ef52==1
keep ef1 ef3 v4 mnr

* ==> Sortierung ... mnr
sort ef1 ef3 v4 mnr

rename mnr ef5a

gen m_kids=1
collapse (count) m_kids, by(ef1 ef3 v4 ef5a)
label var m_kids "Anzahl lediger Kinder einer Mutter"
save temp_M1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 ef5a

* Anzahl der Kinder den Muettern zuspielen 
merge m:m ef1 ef3 v4 ef5a using temp_M1.dta
* browse ef1 ef3 v4 ef5a ef54 ef55 mnr m_kids, nolab
* tab _merge ef52, miss
drop _merge

recode m_kids (1/99=1), gen(mutter)
label var mutter "Mutter lediger Kinder im HH"
* browse ef1 ef3 v4 ef5a ef52 ef53 mnr m_kids mutter, nolab

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if (mutter==1)
keep  ef1 ef3 v4 ef5a mig1b vorl jzuzug ef366 ef372 
rename ef5a   mnr
rename jzuzug jzuzug_M
rename ef366  ef366_M
rename ef372  ef372_M
rename mig1b  mig_M
rename vorl   vorl_M

sort ef1 ef3 v4 mnr
save temp_M1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 mnr

* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M1.dta
* tab _merge ef52, miss
drop _merge
* tab mig_M mutter

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 v4 ef5a

gen mig1c=mig1b
replace mig1c=22 if (mig1b==31  /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                 & jzuzug>10    /// und valides Zuzugsjahr
                 & ef52==1      /// Mutter im Haushalt (ergaenzt)
                 & (abs(jzuzug-jzuzug_M)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr der Mutter
                 & vorl_M==1)   //  Mutter ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949
* n=17 Rekodierungen MIG=31 -> MIG=22
label var mig1c "Migrationsstatus nach Plausib a) Ehegatte + b) Vater + c) Mutter"

gen mig2 = mig1c
label var mig2 "Migrationsstatus nach Plausibilisierungen (MIG=31, a-c)"
/* label def mig2 ///
    0 "SYSMIS" ///
   11 "Vertriebene vor 1950" ///
   21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "zugewanderte/r Auslaender/in" ///
   42 "nicht zugewanderte/r Auslaender/in" ///
   77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "fehlende/unvollstaendige Angaben" */
* tab mig2, miss
   
* Ausgangssortierung
sort ef1 ef3 v4 v5

/* ----------------------------------------------------------------------------
1a Typisierung des Migrationshintergrundes nicht im Haushalt lebender Eltern
   Angaben zum Vater: Nomenklatur wie oben mit Suffix VE (Vater extern) 
   Bearbeitung nur, wenn Vater nicht im Haushalt lebt, d.h. wenn EF357=8 
Vorbelegung: keine Angaben zu Vater im HH */
gen isve=0 
label var isve "Vater lebt im Haushalt"
label def isve 0 "[0] ja" 1 "[1] nein (ef357=8)"
label val isve isve
gen zuzugve=.
gen jzuzugve=.
gen auslve=.
gen sadoppve=.
gen sa1ve=.
gen sa2ve=.
gen sa3ve=. 
gen spaussve=.
gen eingebve=.
gen jeinbve=.
gen save=.
gen sa_erwve=.

* Vater lebt nicht im Haushalt (EF357=8) 
replace isve=1        if (ef357==8)
replace zuzugve=ef358 if (ef357==8)
recode zuzugve (1=1) (7 8=0) (*=.) if (ef357==8)
replace jzuzugve=ef359 if (ef357==8)
recode  jzuzugve (9999=9) (-5=.) if (ef357==8), copyrest

* nur deutsche SA 
replace auslve=0    if (ef357==8 & zuzugve==1 & ef360==1)
replace sadoppve=0  if (ef357==8 & zuzugve==1 & ef360==1)
replace sa1ve= 0    if (ef357==8 & zuzugve==1 & ef360==1)

* deutsche und auslaendische SA 
replace auslve=0    if (ef357==8 & zuzugve==1 & ef360==2)
replace sadoppve=1  if (ef357==8 & zuzugve==1 & ef360==2)
replace sa2ve=99    if (ef357==8 & zuzugve==1 & ef360==2 & ef361==-5)
replace sa2ve=ef361 if (ef357==8 & zuzugve==1 & ef360==2 & ef361!=-5)

* nur auslaendische SA oder SAs 
replace auslve=1    if (ef357==8 & zuzugve==1 & ef360==8)
replace sa1ve=99    if (ef357==8 & zuzugve==1 & ef360==8 & ef361==-5)
replace sa1ve=ef361 if (ef357==8 & zuzugve==1 & ef360==8 & ef361!=-5)
replace sadoppve=0  if (ef357==8 & zuzugve==1 & ef360==8 & ef362<1) // 0 und -5 als SYSMIS behandeln
replace sadoppve=1  if (ef357==8 & zuzugve==1 & ef360==8 & ef362>0) // 0 und -5 als SYSMIS behandeln 
* DEAKTIVIERT: replace sa2ve=ef362 if (ef357==8 & zuzugve==1 & ef360==8 & ef362>0) // 0 und -5 als SYSMIS behandeln

* 'entfaellt' Auspraegung 
replace auslve=.    if (ef357==8 & zuzugve==1 & ef360==-5)
replace sadoppve=.  if (ef357==8 & zuzugve==1 & ef360==-5)
replace sa1ve=.     if (ef357==8 & zuzugve==1 & ef360==-5)
replace sa2ve=.     if (ef357==8 & zuzugve==1 & ef360==-5)
replace sa3ve=.     if (ef357==8 & zuzugve==1 & ef360==-5)

* ab hier nur noch Deutsche...  Spaetaussiedler ohne Einbuergerung
replace spaussve=1  if (ef357==8 & zuzugve==1 & auslve==0 & ef363==2)
replace eingebve=0  if (ef357==8 & zuzugve==1 & auslve==0 & ef363==2)
replace jeinbve=.   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==2)
replace sa3ve=ef365 if (ef357==8 & zuzugve==1 & auslve==0 & ef363==2 & ef365!=-5) // SA vor Zuzug 
replace sa2ve=ef361 if (ef357==8 & zuzugve==1 & auslve==0 & ef363==2 & ef361!=-5) // 2. SA 

* Spaetaussiedler mit Einbuergerung 
replace spaussve=1    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3)
replace eingebve=1    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3)
replace jeinbve=9     if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3 & ef364==9999) // Einbuergerungsjahr 
replace jeinbve=ef364 if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3 & ef364!=9999 & ef364!=-5)
replace sa3ve=ef365   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3 & ef365!=-5)  // SA vor Zuzug 
replace sa2ve=ef361   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==3 & ef361!=-5)  // 2. SA  -5 => sysmis ? 

* sonstige Einbuergerung 
replace spaussve=0    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4)
replace eingebve=1    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4)
replace jeinbve=9     if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4 & ef364==9999) // Einbuergerungsjahr 
replace jeinbve=ef364 if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4 & (ef364!=9999 & ef364!=-5))
replace sa3ve=ef365   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4 & ef365!=-5) // SA vor Einbuergerung 
replace sa2ve=ef361   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==4 & ef361!=-5) // 2. SA 

* Deutsche durch Geburt 
replace spaussve=0    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1)
replace eingebve=0    if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1)
replace jeinbve=.     if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1)
replace sa3ve=0       if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1)
replace sa1ve=0       if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1)
replace sa2ve=ef361   if (ef357==8 & zuzugve==1 & auslve==0 & ef363==1 & ef361!=-5) // 2. SA 

* A1) Auslaender, im Ausland geboren 
gen migve=41           if (ef357==8 & zuzugve==1 & auslve==1)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==1)
replace sa_erwve=sa1ve if (ef357==8 & zuzugve==1 & auslve==1) // SA und SA_erw: auslaendische SA 

* ... als Deutscher zugewandert A2) Spaetaussiedler/in mit Einbuergerung 
replace migve=25       if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==1)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==1)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==1)
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==1 & sa_erwve==.)
replace sa_erwve=99    if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==1 & sa_erwve==.)

* Spaetaussiedler ohne Einbuergerung 
replace migve=21       if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==0) 
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==0)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==0)
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==0 & sa_erwve==.)
replace sa_erwve=99    if (ef357==8 & zuzugve==1 & auslve!=1 & spaussve==1 & eingebve==0 & sa_erwve==.)

* kein Spaetaussiedler ... A3) Eingebuergerte/r 
replace migve=31       if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==1)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==1)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==1)
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==1 & sa_erwve==.)
replace sa_erwve=99    if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==1 & sa_erwve==.)

* Deutsch durch Geburt
replace migve=77       if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==0)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==0)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==0)
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==0 & sa_erwve==.)
replace sa_erwve=99    if (ef357==8 & zuzugve==1 & auslve==0 & spaussve==0 & eingebve==0 & sa_erwve==.)

replace migve=77       if (zuzugve==0)
replace auslve=.       if (zuzugve==0)
replace auslve=.       if (zuzugve==0)
replace spaussve=.     if (zuzugve==0)
replace eingebve=.     if (zuzugve==0)
replace jeinbve=.      if (zuzugve==0)
replace sadoppve=.     if (zuzugve==0)
replace sa1ve=0        if (zuzugve==0)
replace save=sa1ve     if (zuzugve==0)
replace sa_erwve=0     if (zuzugve==0)
replace sa_erwve=sa3ve if (zuzugve==0 & sa3ve>=0 & sa3ve<=98)
replace sa_erwve=sa2ve if (zuzugve==0 & sa2ve>=0 & sa2ve<=98)

* Restliche Faelle: uneindeutig: im Ausland verblieben oder lebte bereits hier
replace migve=77       if (zuzugve==.)
replace jzuzugve=.     if (zuzugve==.)
replace auslve=.       if (zuzugve==.)
replace spaussve=.     if (zuzugve==.)
replace eingebve=.     if (zuzugve==.)
replace jeinbve=.      if (zuzugve==.)
replace sadoppve=.     if (zuzugve==.)
replace sa1ve=0        if (zuzugve==.)
replace save=sa1ve     if (zuzugve==.)
replace sa_erwve=0     if (zuzugve==.)
replace sa_erwve=sa3ve if (zuzugve==. & sa3ve>=0 & sa3ve<=98)
replace sa_erwve=sa2ve if (zuzugve==. & sa2ve>=0 & sa2ve<=98)
replace zuzugve=.      if (zuzugve==.)
recode zuzugve (1=1) (*=.) if (zuzugve==.)

* Kontrolle
* tab1 migve sa1ve sa2ve sa3ve save sa_erwve, nolab miss

label var migve "Migrationshintergrundes des Vaters (nicht im Haushalt lebend)"
/* lab def migve 11 "Vertriebene vor 1950" ///
              21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
              22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
              25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
              29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
              31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
              32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
              41 "zugewanderte/r Auslaender/in" /// 
              42 "nicht zugewanderte/r Auslaender/in" ///
              77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler | inkl. REST" ///
              99 "fehlende/unvollstaendige Angaben" 
label val migve migve */
 
label var zuzugve "Zuzug des Vaters (ex EF358)" 
label def zuzugve 1 "nach 1960 zugezogen = foreign born (EF358=1)" /// 
                  0 "vor 1960 oder nicht zugezogen (EF358=7,8)" 
*                 . "k.A. (EF358=9)"
label val zuzugve zuzugve 
 
label var jzuzugve "Jahr des Zuzugs des Vaters (ex EF359)" 
label def jzuzugve 9 "k.A. zum Zuzugsjahr (EF359=9999)" 
*                1960 - 2009: jeweiliges Jahr
*                   . "kein Zuzug"  
label val jzuzugve jzuzugve
 
label var auslve "Staatsangehoerigkeit des Vaters" 
label def auslve  0 "deutsche Staatsangehoerigkeit (einschliesslich doppelte)" ///
                  1 "nicht-deutsche Staatsangehoerigkeit"
label val auslve auslve
 
label var spaussve "Deutsche Staatsangehoerigkeit des Vaters als Spaetaussiedler mit/ohne Einbuergerung"
lab def spaussve 1 "Spaetaussiedler"
lab val spaussve spaussve

label var eingebve "Deutsche Staatsangehoerigkeit des Vaters durch Einbuergerung"
label def eingebve 1 "Eingebuergert"
label val eingebve eingebve
 
label var jeinbve "Jahr der Einbuergerung des Vaters"
label def jeinbve 9 "k.A." 
*                -5 "Entfaellt (Person ohne deutsche Staatsangehoerigkeit; Spaetaussiedler ohne Einbuergerung)" 
label val jeinbve jeinbve

label var sadoppve "Doppelte Staatsangehoerigkeit des Vaters" 
lab def sadoppve 0 "keine doppelte Staatsangehoerigkeit" ///
                 1 "doppelte Staatsangehoerigkeit"
lab val sadoppve sadoppve
 
label var save "aktuelle Staatsangehoerigkeit des Vaters" 

label var sa1ve "Aktuelle (erste) Staatsangehoerigkeit des Vaters"
 
label var sa2ve "Aktuelle (zweite) Staatsangehoerigkeit des Vaters" 
 
label var sa3ve "Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF365)"
 
label var sa_erwve "erweiterte aktuelle Staatsangehoerigkeit des Vaters"

/* ----------------------------------------------------------------------------
####### Nationalitaet und Staatsangehoerigkeit der Mutter #######
Angaben zur Mutter: Nomenklatur wie oben mit Suffix ME (Mutter extern) 
Bearbeitung nur, wenn Mutter nicht im Haushalt lebt, d.h. wenn EF349=8 */

* Vorbelegung: keine Angaben zur Mutter im HH
gen isme=0
label var isme "Mutter lebt im Haushalt"
label def isme  0 "ja" 1 "nein (ef349=8)"
label val isme isme
gen zuzugme=.
gen jzuzugme=.
gen auslme=.
gen sadoppme=.
gen sa1me=.
gen sa2me=.
gen sa3me=. 
gen spaussme=.
gen eingebme=.
gen jeinbme=.
gen same=.
gen sa_erwme=.

* Mutter lebt nicht im Haushalt 
replace isme=1 if (ef349==8) 
replace zuzugme = ef350 if (ef349==8) 
recode zuzugme (1=1) (7 8=0) (*=.) if (ef349==8)
replace jzuzugme=ef351 if (ef349==8)
recode jzuzugme (9999=9) (-5=.) if (ef349==8), copyrest

* nur deutsche SA
replace auslme=0    if (ef349==8 & zuzugme==1 & ef352==1)
replace sadoppme=0  if (ef349==8 & zuzugme==1 & ef352==1)
replace sa1me=0     if (ef349==8 & zuzugme==1 & ef352==1)

* deutsche und auslaendische SA
replace auslme=0    if (ef349==8 & zuzugme==1 & ef352==2)
replace sadoppme=1  if (ef349==8 & zuzugme==1 & ef352==2)
replace sa2me=99    if (ef349==8 & zuzugme==1 & ef352==2 & ef353==-5)
replace sa2me=ef353 if (ef349==8 & zuzugme==1 & ef352==2 & ef353!=-5)

* nur auslaendische SA oder SAs
replace auslme=1    if (ef349==8 & zuzugme==1 & ef352==8)
replace sa1me=99    if (ef349==8 & zuzugme==1 & ef352==8 & ef353==-5)
replace sa1me=ef353 if (ef349==8 & zuzugme==1 & ef352==8 & ef353!=-5)
replace sadoppme=0  if (ef349==8 & zuzugme==1 & ef352==8 & ef354<1) // 0 und -5: SYSMIS
replace sadoppme=1  if (ef349==8 & zuzugme==1 & ef352==8 & ef354>0) // 0 und -5: SYSMIS
* DEAKTIVIERT: replace sa2me=ef354 if (ef349==8 & zuzugme==1 & ef352==8 & ef354>0) // 0 und -5: SYSMIS

* 'entfaellt' Auspraegung 
replace auslme=.    if (ef349==8 & zuzugme==1 & ef352==-5)
replace sadoppme=.  if (ef349==8 & zuzugme==1 & ef352==-5) 
replace sa1me=.     if (ef349==8 & zuzugme==1 & ef352==-5)
replace sa2me=.     if (ef349==8 & zuzugme==1 & ef352==-5)
replace sa3me=.     if (ef349==8 & zuzugme==1 & ef352==-5)

* ab hier nur noch Deutsche ...  Spaetaussiedler ohne Einbuergerung
replace spaussme=1  if (ef349==8 & zuzugme==1 & auslme==0 & ef355==2)
replace eingebme=0  if (ef349==8 & zuzugme==1 & auslme==0 & ef355==2)
replace jeinbme=.   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==2)
replace sa3me=ef382 if (ef349==8 & zuzugme==1 & auslme==0 & ef355==2 & ef382!=-5) // SA vor Zuzug
replace sa2me=ef353 if (ef349==8 & zuzugme==1 & auslme==0 & ef355==2 & ef353!=-5) // 2. SA

* Spaetaussiedler mit Einbuergerung 
replace spaussme=1    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3)
replace eingebme=1    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3)
replace jeinbme=9     if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3 & ef356==9999) // Einbuergerungsjahr 
replace jeinbme=ef356 if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3 & ef356!=9999 & ef356!=-5)
replace sa3me=ef382   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3 & ef382!=-5)  // SA vor Zuzug 
replace sa2me=ef353   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==3 & ef353!=-5)  // 2. SA

* sonstige Einbuergerung
replace spaussme=0    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4)
replace eingebme=1    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4)
replace jeinbme=9     if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4 & ef356==9999) // Einbuergerungsjahr 
replace jeinbme=ef356 if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4 & (ef356!=9999 & ef356!=-5))
replace sa3me=ef382   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4 & ef382!=-5)   // SA vor Einbuergerung 
replace sa2me=ef353   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==4 & ef353!=-5)   // 2. SA 

* Deutsche durch Geburt
replace spaussme=0    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1)
replace eingebme=0    if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1)
replace jeinbme=.     if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1)
replace sa3me=0       if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1)
replace sa1me=0       if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1)
replace sa2me=ef353   if (ef349==8 & zuzugme==1 & auslme==0 & ef355==1 & ef353!=-5) // 2. SA 

* A1) Auslaender, im Ausland geboren
gen migme=41           if (ef349==8 & zuzugme==1 & auslme==1)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==1)
replace sa_erwme=sa1me if (ef349==8 & zuzugme==1 & auslme==1) // SA und SA_erw: auslaendische SA 

* ... als Deutscher zugewandert A2) Spaetaussiedler/in mit Einbuergerung
replace migme=25       if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==1)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==1)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==1)
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==1 & sa_erwme==.)
replace sa_erwme=99    if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==1 & sa_erwme==.)

* Spaetaussiedler ohne Einbuergerung
replace migme=21       if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==0)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==0)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==0)
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==0 & sa_erwme==.)
replace sa_erwme=99    if (ef349==8 & zuzugme==1 & auslme!=1 & spaussme==1 & eingebme==0 & sa_erwme==.)

* kein Spaetaussiedler ... A3) Eingebuergerte/r 
replace migme=31       if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==1)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==1)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==1)
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==1 & sa_erwme==.)
replace  sa_erwme=99   if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==1 & sa_erwme==.)

* Deutsch durch Geburt 
replace migme=77       if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==0)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==0)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==0)
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==0 & sa_erwme==.)
replace sa_erwme=99    if (ef349==8 & zuzugme==1 & auslme==0 & spaussme==0 & eingebme==0 & sa_erwme==.)

replace migme=77       if (zuzugme==0)
replace jzuzugme=.     if (zuzugme==0)
replace auslme=.       if (zuzugme==0)
replace spaussme=.     if (zuzugme==0)
replace eingebme=.     if (zuzugme==0)
replace jeinbme=.      if (zuzugme==0)
replace sadoppme=.     if (zuzugme==0)
replace sa1me=0        if (zuzugme==0)
replace same=sa1me     if (zuzugme==0)
replace sa_erwme=0     if (zuzugme==0)
replace sa_erwme=sa3me if (zuzugme==0 & sa3me>=0 & sa3me<=98)
replace sa_erwme=sa2me if (zuzugme==0 & sa2me>=0 & sa2me<=98)

* Restliche Faelle: uneindeutig: im Ausland verblieben oder lebte bereits hier
replace migme=77        if (zuzugme==.)
replace jzuzugme=.      if (zuzugme==.)
replace auslme=.        if (zuzugme==.)
replace spaussme=.      if (zuzugme==.)
replace eingebme=.      if (zuzugme==.)
replace jeinbme=.       if (zuzugme==.)
replace sadoppme=.      if (zuzugme==.)
replace sa1me=0         if (zuzugme==.)
replace same=sa1me      if (zuzugme==.)
replace sa_erwme=0      if (zuzugme==.)
replace sa_erwme=sa3me  if (zuzugme==. & sa3me>=0 & sa3me<=98)
replace sa_erwme=sa2me  if (zuzugme==. & sa2me>=0 & sa2me<=98)
replace zuzugme=.   	if (zuzugme==.)
recode zuzugme (1=1) (*=.)  if (zuzugme==.)

* tab1 migme sa1me sa2me sa3me same sa_erwme, nolab miss

label var migme "Migrationshintergrundes der Mutter (nicht im Haushalt lebend)"
/* lab def migme 11 "Vertriebene vor 1950" ///
              21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
              22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
              25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
              29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
              31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
              32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
              41 "zugewanderte/r Auslaender/in" ///
              42 "nicht zugewanderte/r Auslaender/in"  ///
              77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler | inkl. REST" ///
              99 "fehlende/unvollstaendige Angaben" 
label val migme migme */

label var zuzugme "Zuzug der Mutter (ex EF350)"
label def zuzugme 1 "nach 1960 zugezogen = foreign born (EF350=1)"
*               0 "vor 1960 oder nicht zugezogen (EF350=7,8)" => sysmis
*               . "k.A. (EF350=9)"
label val zuzugme zuzugme

label var jzuzugme "Jahr des Zuzugs der Mutter (ex EF351)"
label def jzuzugme 9 "k.A. zum Zuzugsjahr (EF351=9999)"
*                1960 - 2009: jeweiliges Jahr 
*                   . "kein Zuzug" 
label val jzuzugme jzuzugme

label var auslme "Staatsangehoerigkeit der Mutter"
label def auslme  0 "deutsche Staatsangehoerigkeit (einschliesslich doppelte)" ///
                  1 "nicht-deutsche Staatsangehoerigkeit"
label val auslme auslme

label var spaussme "Deutsche Staatsangehoerigkeit der Mutter als Spaetaussiedler mit/ohne Einbuergerung"
label def spaussme 1 "Spaetaussiedler"
label val spaussme spaussme

label var eingebme "Deutsche Staatsangehoerigkeit der Mutter durch Einbuergerung"
label def eingebme 1 "Eingebuergert"
label val eingebme eingebme

label var jeinbme "Jahr der Einbuergerung der Mutter"
label def jeinbme 9 "k.A." ///
                 -5 "Entfaellt (Person ohne deutsche Staatsangehoerigkeit; Spaetaussiedler ohne Einbuergerung)"
label val jeinbme jeinbme

label var sadoppme "doppelte Staatsangehoerigkeit der Mutter"
label def sadoppme 0 "keine doppelte Staatsangehoerigkeit" ///
                   1 "doppelte Staatsangehoerigkeit"
label val sadoppme sadoppme

label var same "aktuelle Staatsangehoerigkeit der Mutter"

label var sa1me "Aktuelle (erste) Staatsangehoerigkeit der Mutter"

label var sa2me "Aktuelle (zweite) Staatsangehoerigkeit der Mutter"

label var sa3me "Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF382)"

label var sa_erwme "Erweiterte aktuelle Staatsangehoerigkeit der Mutter"

gen sa_erw2 = sa_erw
label var sa_erw2 "Erw. Staatsangeh. nach Plausibil."

* Zwischenspeicherung NACH GRUNDTYPISIERUNG & PLAUSIBILISIERUNG
save "temp_mig2.dta", replace

* Kontrolle
* tab1 mig1 mig2 sa_erw migve sa_erwve migme sa_erwme, nolab miss


/* ====================================================================
2. Identifikation von 3-Generationen-Haushalten
   Fuer die nachfolgende Typisierung des Migrationshintergrundes
   von Eltern unter Verwendung von Angaben der Grosseltern werden
   in diesem Schritt 3-Generationen-Haushalte identifiziert und
   Identifikatoren fuer Grossmuetter- und -vaeter gebildet. */

* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter:
*   Personennummer der Grossmutter
generate gmnr = ( (mutter==1 | vater==1) & ef52==1) * ef53

* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: 
*   Personennummer des Grossvaters 
generate gvnr = ( (mutter==1 | vater==1) & ef54==1) * ef55

egen min_gmnr = min(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen max_gmnr = max(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen min_gvnr = min(gvnr * (gvnr>0)), by(ef1 ef3 v4)
egen max_gvnr = max(gvnr * (gvnr>0)), by(ef1 ef3 v4)

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH?
tab max_gmnr min_gmnr if max_gmnr!=min_gmnr & (min_gmnr>0)

* Kontrolle: mehr als 1 Grossvater(nummer) im HH?
tab max_gvnr min_gvnr if max_gvnr!=min_gvnr & (min_gvnr>0)

* Grossvater-/mutter
gen gmutter = (max_gmnr==ef5a) if max_gmnr>0
gen gvater  = (max_gvnr==ef5a) if max_gvnr>0

* Kontrolle: Anzahl Grossmuetter/-vaeter im HH
egen n_gm = total(gmutter), by(ef1 ef3 v4) 
egen n_gv = total(gvater), by(ef1 ef3 v4) 
bysort ef1 ef3 v4: gen HV = _n
* tab n_gm n_gv, miss

* Ausgangssortierung
sort ef1 ef3 v4 v5

/* ====================================================================
3. Endtypisierung der Grosseltern

Angaben zu den im Haushalt lebenden Eltern
Vater:    migv  sa1v  sa2v  sa3v  sav  sa_erwv
Mutter:   migm  sa1m  sa2m  sa3m  sam  sa_erwm

Angaben zum den nicht im Haushalt lebenden Eltern
Vater:   migve sa1ve sa2ve sa3ve save sa_erwve 
Mutter:  migme sa1me sa2me sa3me same sa_erwme */

* ------- ZUNAECHST NUR DIE IM HAUSHALT LEBENDEN GROSSELTERN ------- 

* Sichern des Migrationsstatus vor Endtypisierung Grosseltern
rename mig2 mig2a
label var mig2a "Migrationsstatus nach Plausibilisierungen (MIG=31, a-c), vor Endtypisierung Grosseltern"

* Nur fuer die als Grossvater bzw. Grossmutter gekennzeichneten Personen
* Bei Grosseltern liegen nur externe Angaben (*VE, *ME) vor

* Angaben zum Grossvater
gen migv    = migve    if (gvater==1 | gmutter==1)
gen sa1v    = sa1ve    if (gvater==1 | gmutter==1)
gen sa2v    = sa2ve    if (gvater==1 | gmutter==1)
gen sa3v    = sa3ve    if (gvater==1 | gmutter==1)
gen sav     = save     if (gvater==1 | gmutter==1)
gen sa_erwv = sa_erwve if (gvater==1 | gmutter==1)

* Angaben zur Grossmutter
gen migm    = migme    if (gvater==1 | gmutter==1)
gen sa1m    = sa1me    if (gvater==1 | gmutter==1)
gen sa2m    = sa2me    if (gvater==1 | gmutter==1)
gen sa3m    = sa3me    if (gvater==1 | gmutter==1)
gen sam     = same     if (gvater==1 | gmutter==1)
gen sa_erwm = sa_erwme if (gvater==1 | gmutter==1)

label var migv "Migrationsstatus Vater - vorl. nur fuer Grosseltern"
label var migm "Migrationsstatus Mutter - vorl. nur fuer Grosseltern"

recode mig2a (11 21 22 25 29 31 41=.) (*=1) if (gvater==1 | gmutter==1), gen(konvproc) // ex: recode mig2a (11 21 29 31 41=.) (*=1) if (gvater==1 | gmutter==1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle - im Inland geborene GROSSELTERN"


/* conversion.dta --- ex: conversion_2011.xls --- 
 obs:         1,163
 vars:            6
variable name   variable label
---------------------------------------------------------------------------------------------------------------------------------------
_mig_           Migrationsstatus Befragter VOR Konversion
_migv_          Migrationsstatus Vater
_migm_          Migrationsstatus Mutter
konvproc        Konstante (1) fuer Konversionsprozedur
migneu          Migrationsstatus Befragter konvertiert
kennung                           
*/

gen _mig_  = mig2a if (konvproc==1) // MIG-Status vor Konversion, SPSS: mig_k
gen _migv_ = migv  if (konvproc==1) // MIG-Status Vater                 migv_k
gen _migm_ = migm  if (konvproc==1) // MIG-Status Mutter                migm_k
recode _migv_ (.=99) (22 23=21) if (konvproc==1)
recode _migm_ (.=99) (22 23=21) if (konvproc==1)

* Sortierung fuer Konversionsprozedur
sort _mig_ _migv_ _migm_ konvproc

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 v5

* Uebernahme konvertierter MIG-Typisierung
gen mig2 = migneu if (migneu!=.)
replace mig2 = mig2a if (migneu==.)

* Aenderungen nach Konversion
* tab mig2 mig2a if mig2!=mig2a, miss

label var mig2 "Migrationsstatus nach Endtypisierung Grosseltern"
/* label drop mig2
label def mig2 /// 
    0 "SYSMIS; Deutsch ohne Migrationshintergrund" ///
   11 "Vertriebene vor 1950" ///
   21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "zugewanderte/r Auslaender/in" ///
   42 "nicht zugewanderte/r Auslaender/in" ///
   43 "Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren" ///
   62 "Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
   77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "fehlende/unvollstaendige Angaben"
label val mig2 mig2 
numlabel mig2, add mask("[#] ") force
*/

/* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag
        ergaenzen, sofern noetig und moeglich 
    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern */
gen sa_erw0 = sa_erw
replace sa_erw=sa_erwv if ( konvproc==1 & (sa_erw==0 | sa_erw==99) & (sa_erwv>0 & sa_erwv<99) )
replace sa_erw=sa_erwm if ( konvproc==1 & (sa_erw==0 | sa_erw==99) & (sa_erwm>0 & sa_erwm<99) )

gen sa_erw3 = sa_erw
label var sa_erw3 "Erw. Staatsangeh. nach Endtypis. Grosseltern"

* Variablen aus Datei conversion.dta loeschen
drop _mig_ _migv_ _migm_ migneu kennung

* Zwischensicherung
save "temp_mig2a.dta", replace

* Kontrolle
* tab1 mig2 sa_erw, miss


/* ====================================================================
4. Endtypisierung der Eltern
   Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
   vorlaeufigen Migrationsstatus wird der resultierende endgueltige 
   Migrationsstatus zugewiesen. Diese Konversions-Prozedur wird nur 
   fuer im Inland Geborene angewandt.
   Abschliessend wird die Variable erweiterte Staatsangehoerigkeit
   (SA_erw) ggf. durch Informationen zum Vater bzw. zur Mutter ergaenzt. */

* Ausgangssortierung
sort ef1 ef3 v4 v5

* ===== ANGABEN ZU DEM IM HAUSHALT LEBENDEN GROSSELTERN ===== 
* Angaben zum Migrationsstatus des Grossvaters 
egen mig_gv    = max(mig2*(gvater==1)),   by(ef1 ef3 v4)
egen sa1_gv    = max(sa1*(gvater==1)),    by(ef1 ef3 v4)
egen sa2_gv    = max(sa2*(gvater==1)),    by(ef1 ef3 v4)
egen sa3_gv    = max(sa3*(gvater==1)),    by(ef1 ef3 v4)
egen sa_gv     = max(sa*(gvater==1)),     by(ef1 ef3 v4)
egen sa_erw_gv = max(sa_erw*(gvater==1)), by(ef1 ef3 v4)

recode mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv (nonmiss=.) if gvnr!=ef55
format ef3 %5.0f
format ef4 %3.0f
format ef5a vater gvater ef54 ef55 ef44 gvnr %3.0f
format mig2 mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv %2.0f

* Angaben zum Migrationsstatus der Grossmutter
egen mig_gm    = max(mig2*(gmutter==1)),   by(ef1 ef3 v4)
egen sa1_gm    = max(sa1*(gmutter==1)),    by(ef1 ef3 v4)
egen sa2_gm    = max(sa2*(gmutter==1)),    by(ef1 ef3 v4)
egen sa3_gm    = max(sa3*(gmutter==1)),    by(ef1 ef3 v4)
egen sa_gm     = max(sa*(gmutter==1)),     by(ef1 ef3 v4)
egen sa_erw_gm = max(sa_erw*(gmutter==1)), by(ef1 ef3 v4)
recode mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm (nonmiss=.) if gmnr!=ef53
format ef5a mutter gmutter ef52 ef53 gmnr %3.0f
format mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm %2.0f

/* --- NUN AUCH DATEN ZU DEN NICHT IM HAUSHALT LEBENDEN GROSSELTERN ---

Zusammenfuehren der Angaben zu Grosseltern in und ausserhalb des Haushalts
Bei Grosseltern liegen nur externe Angaben vor
ELTERN MIT GROSSELTERN IM HH                   ANGABEN ZU GROSSELTERN
 VATER=1  & (GVNR=EF55): Vater mit Grossvater   MIG_GV, ..., SAerw_GV [VATER]
 VATER=1  & (GMNR=EF53): Vater mit Grossmutter  MIG_GM, ..., SAerw_GM [MUTTER]
 MUTTER=1 & (GVNR=EF55): Mutter mit Grossvater  MIG_GV, ..., SAerw_GV [VATER]
 MUTTER=1 & (GMNR=EF53): Mutter mit Grossmutter MIG_GM, ..., SAerw_GM [MUTTER]

-------------------------------------------------------------------------
Ab hier die eigentliche Endtypisierung des Migrationsstatus der Eltern 
mittels Konversions-Prozedur, bei der nur im Inland Geborene beruecksichtigt
werden 
*/
drop konvproc // Fassung Endtypisierung Grosseltern

recode mig2 (11 21 22 23 25 29 31 41=.) (else=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

gen egre=1 if ( (vater==1  & (gvnr==ef55)) | /// Vater mit Grossvater 
                (vater==1  & (gmnr==ef53)) | /// Vater mit Grossmutter 
                (mutter==1 & (gvnr==ef55)) | /// Mutter mit Grossvater 
                (mutter==1 & (gmnr==ef53)))  //  Mutter mit Grossmutter 
label var egre "Eltern mit Grosseltern im Haushalt"
format konvproc egre %1.0f

* Typisierung Eltern-Grosseltern
gen egretyp=0
replace egretyp=1 if (vater==1  & gvnr==ef55)              // Vater mit Grossvater 
replace egretyp=2 if (vater==1  & gmnr==ef53)              // Vater mit Grossmutter 
replace egretyp=3 if (vater==1  & gvnr==ef55 & gmnr==ef53) // Vater mit Grossvater und -mutter
replace egretyp=4 if (mutter==1 & gvnr==ef55)              // Mutter mit Grossvater 
replace egretyp=5 if (mutter==1 & gmnr==ef53)              // Mutter mit Grossmutter
replace egretyp=6 if (mutter==1 & gvnr==ef55 & gmnr==ef53) // Mutter mit Grossvater und -mutter
label var egretyp "Eltern mit Grosseltern im Haushalt"
label def egretyp 0 "TNZ"  ///
   1 "Vater mit Grossvater"  2 "Vater mit Grossmutter"  3 "Vater mit Grosseltern" ///
   4 "Mutter mit Grossvater" 5 "Mutter mit Grossmutter" 6 "Mutter mit Grosseltern"
label val egretyp egretyp   
format egretyp %1.0f

* Vorbereitung  mit conversion.dta
*     konvproc=1: Nur im Inland geborene Eltern 
* MIG-Status Eltern vor Konversion
gen _mig_  = mig2   if (konvproc==1 & (vater==1 | mutter==1))
* MIG-Status der nicht im Haushalt lebenden Grosseltern 
gen _migv_ = migve  if (isve==1 & konvproc==1 & (vater==1 | mutter==1))
gen _migm_ = migme  if (isme==1 & konvproc==1 & (vater==1 | mutter==1))
* MIG-Status der im Haushalt lebenden Grosseltern
replace _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==1 // Vater mit Grossvater im HH
replace _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==2 // Vater mit Grossmutter im HH
replace _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==3 // Vater mit Grossvater und -mutter
replace _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==3 // Vater mit Grossvater und -mutter
replace _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==4 // Mutter mit Grossvater 
replace _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==5 // Mutter mit Grossmutter
replace _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==6 // Mutter mit Grossvater und -mutter
replace _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1)) & egretyp==6 // Mutter mit Grossvater und -mutter
format _mig_ _migv_ _migm_ %2.0f

recode _migv_ _migm_ (.=99) if (konvproc==1 & (vater==1 | mutter==1)), copyrest

/* Externe Angaben fuer Grosseltern (siehe oben Endtypis. Grosseltern)
   umbenennen oder loeschen */
drop migv sa1v sa2v sa3v sav
rename sa_erwv sa_erwgv
drop migm sa1m sa2m sa3m sam
rename sa_erwm sa_erwgm

* Staatsangehoerigkeit erweitert (SA_erw) der Eltern (die nicht Grosseltern sind)
gen sa_erwv = sa_erwve if (isve==1) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Vater lebt nicht im HH
                                        (mutter==1 & (gmutter==0 | gmutter==.)))
gen sa_erwm = sa_erwme if (isme==1) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Mutter lebt nicht im HH
                                        (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwv = sa_erw_gv if (egretyp==1) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Vater mit Grossvater im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwm = sa_erw_gm if (egretyp==2) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Vater mit Grossmutter im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwv = sa_erw_gv if (egretyp==3) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Vater mit Grosseltern im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwm = sa_erw_gm if (egretyp==3) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Vater mit Grosseltern im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwv = sa_erw_gv if (egretyp==4) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Mutter mit Grossvater im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )   
replace sa_erwm = sa_erw_gm if (egretyp==5) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Mutter mit Grossmutter im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwv = sa_erw_gv if (egretyp==6) & ((vater==1  & (gvater==0  | gvater==.)) | /// Mutter mit Grosseltern im HH
                                               (mutter==1 & (gmutter==0 | gmutter==.)) )
replace sa_erwm = sa_erw_gm if (egretyp==6) & ( (vater==1  & (gvater==0  | gvater==.)) | /// Mutter mit Grosseltern im HH
                                                (mutter==1 & (gmutter==0 | gmutter==.)) )
recode sa_erwv sa_erwm (.=99) if ( (vater==1  & (gvater==0  | gvater==.)) | /// 
                                   (mutter==1 & (gmutter==0 | gmutter==.)) ), copyrest
format sa_erwv sa_erwm %2.0f

* Sortierung fuer Konversionsprozedur
sort _mig_ _migv_ _migm_ konvproc

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 v5

* Uebernahme konvertierter MIG-Typisierung
gen mig3 = migneu if (migneu!=.)
replace mig3 = mig2 if (migneu==.)
format mig3 %2.0f

label var mig3 "Migrationsstatus nach Endtypisierung Eltern"
/* label def mig3 ///
    0 "nicht zuordenbar (Rest)" ///
   11 "Vertriebene vor 1950" ///
   21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "(Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "zugewanderte/r Auslaender/in" ///
   42 "nicht zugewanderte/r Auslaender/in" ///
   43 "nicht zugewanderte/r Auslaender/in, beide Eltern hier geboren" ///
   52 "Deutscher mit einseitigem Migrationshintergrund" ///
   53 "Deutscher mit einseitigem Migrationshintergrund" ///
   54 "Deutscher mit einseitigem Migrationshintergrund" ///
   62 "Deutscher mit zweiseitigem Migrationshintergrund" ///
   63 "Deutscher mit zweiseitigem Migrationshintergrund" ///
   64 "Deutscher mit zweiseitigem Migrationshintergrund" ///
   77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "fehlende/unvollstaendige Angaben"
label val mig3 mig3 */

/* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag 
        ergaenzen, sofern noetig und moeglich 
    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern */
replace sa_erw0 = sa_erw

* Nur im Inland geborene Eltern (ohne Grosseltern)
replace sa_erw = sa_erwv if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                            (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
		                    ( (sa_erw==0 | sa_erw==99) & (sa_erwv>0 & sa_erwv<99) ) )
replace sa_erw = sa_erwm if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                            (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
		                    ( (sa_erw==0 | sa_erw==99) & (sa_erwm>0 & sa_erwm<99) ) )

gen sa_erw4 = sa_erw
label var sa_erw4 "Erw. Staatsangeh. zu MIG3 - nach Endtypis. der Eltern"
format sa_erw4 %2.0f

* Ausgangssortierung
sort ef1 ef3 v4 v5

* Kontrollvariable sa_erw0 loeschen
drop sa_erw0

* Zwischenspeicherung MIG nach Endtypisierung der Eltern
save "temp_mig3.dta", replace 

* Kontrolle
* tab1 mig3 sa_erw, miss nolab


/* ====================================================================
5. Endtypisierung Befragte
   Analog zur Endtypisierung der Eltern wird der endgueltige 
   Migrationsstatus unter Beruecksichtigung der Kombinationen von 
   eigenem, vaeterlichen und muetterlichen vorlaeufigen Migrationsstatus
   zugewiesen, wobei auch hier die Zuweisungen nur fuer die im Inland 
   Geborenen zur Anwendung kommen, und die erweiterte 
   Staatsangehoerigkeit (SA_erw) ggf. durch Angaben des Vaters bzw. der
   Mutter ergaenzt wird.
   Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum
   Migrationsstatus (MIGS). */

* Ausgangssortierung
* sort ef1 ef3 v4 v5

* === ZUNAECHST ANGABEN DER IM HAUSHALT LEBENDEN ELTERN  ===

* Migrationsrelevante Eintraege fuer Eltern: mig3 sa1 sa2 sa3 sa sa_erw jzuzug
* vnr = Personennr. des Vaters (EF55)
keep if (vater==1)
keep  ef1 ef3 v4 ef5a mig3 sa1 sa2 sa3 sa sa_erw jzuzug

rename ef5a   vnr
rename mig3   mig_v
rename sa1    sa1_v
rename sa2    sa2_v
rename sa3    sa3_v
rename sa     sa_v
rename sa_erw sa_erw_v
rename jzuzug jzuzug_v

save temp_V2.dta, replace

* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 v4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V2.dta

* tab _merge ef54, miss
drop _merge
* tab mig_v vater

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 v4 v5

save temp_mig3a.dta, replace

* mnr = Personennr. der Mutter (EF53)
keep if (mutter==1)
keep  ef1 ef3 v4 ef5a mig3 sa1 sa2 sa3 sa sa_erw jzuzug

rename ef5a   mnr
rename mig3   mig_m
rename sa1    sa1_m
rename sa2    sa2_m
rename sa3    sa3_m
rename sa     sa_m
rename sa_erw sa_erw_m
rename jzuzug jzuzug_m

save temp_M2.dta, replace

* GESAMTFILE 
use temp_mig3a.dta, clear
sort ef1 ef3 v4 mnr
* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M2.dta

* tab _merge ef52, miss
drop _merge
* tab mig_m mutter

* Sortierung des Ausgangsfiles
sort ef1 ef3 v4 v5
save temp_mig3b.dta, replace

* Vorher zugespielte Variablen aus conversion.dta loeschen
drop _mig_ _migv_ _migm_ konvproc migneu kennung   

* Konversions-Prozedur nur fuer im Inland Geborene 
recode mig3 (11 21 22 23 25 29 31 41=.) (else=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* === BERUECKSICHTIGUNG VON ANGABEN DER NICHT IM HAUSHALT LEBENDEN ELTERN  ===

* Vorbereitung MERGE mit Konversionstabelle (conversion.dta)
* [08-Endtypisierung Befragte normale Jahre.sas (MZ 2008)

* ANGABEN ZU DEN IM HH LEBENDEN ELTERN (s.o.):
* Zum Vater:  mig_v sa1_v sa2_v sa3_v sa_v sa_erw_v jzuzug_v
* Zur Mutter: mig_m sa1_m sa2_m sa3_m sa_m sa_erw_m jzuzug_m

* Kombination Angaben zu Eltern
* PE: EXTERN
generate pe = (isve==0 & isme==0)    // keine externen Angaben zu den Eltern
replace  pe=2 if (isve==1 & isme==1) // externe Angaben zu beiden Eltern
replace  pe=3 if (isve==1 & isme==0) // externe Angaben nur zum Vater
replace  pe=4 if (isve==0 & isme==1) // externe Angaben nur zur Mutter 
format pe %1.0f
label var pe "Externe Angaben zu den Eltern"
label def pe 1 "keine" 2 "beide" 3 "Vater" 4 "Mutter" 0 "sonst"
label val pe pe

* PI: INTERN
generate pi = (ef55<1 & ef53<1)      // keine internen Angaben zu den Eltern
replace  pi = 2 if (ef55>0 & ef53>0) // interne Angaben zu beiden Eltern
replace  pi = 3 if (ef55>0 & ef53<1) // interne Angaben nur zum Vater 
replace  pi = 4 if (ef55<1 & ef53>0) // interne Angaben nur zur Mutter 
format pi %1.0f
label var pi "Interne Angaben zu den Eltern"
label def pi 1 "keine"  2 "beide"  3 "Vater"  4 "Mutter" 0 "sonst"
label val pi pi

* SA_erwV und SA_erwM aus Schritt Endtypisierung Eltern sichern
gen sa_erwv1 = sa_erwv
gen sa_erwm1 = sa_erwm
label var sa_erwv1 "Erw. Staatsangeh. Vater - Endtypis. Eltern"
label var sa_erwm1 "Erw. Staatsangeh. Mutter - Endtypis. Eltern"
format sa_erwv1 sa_erwm1 %2.0f

* Initialisierung SA_erwV und SA_erwM
replace sa_erwv=99
replace sa_erwm=99
format sa_erwv sa_erwm %2.0f

* Vater lebt nicht im HH (isve=1 := ef357=8)
gen migv=migve       if (isve==1)
gen sa1v=sa1ve       if (isve==1)
gen sa2v=sa2ve       if (isve==1)
gen sa3v=sa3ve       if (isve==1)
gen jzuzugv=jzuzugve if (isve==1)
gen sav=save         if (isve==1)
replace sa_erwv=sa_erwve if (isve==1)

* Gueltige Angaben zu dem im HH lebenden Vater
replace migv=mig_v        if (mig_v!=.)
replace sa1v=sa1_v        if (mig_v!=.)
replace sa2v=sa2_v        if (mig_v!=.)
replace sa3v=sa3_v        if (mig_v!=.)
replace jzuzugv=jzuzug_v  if (mig_v!=.)
replace sav=sa_v          if (mig_v!=.)
replace sa_erwv=sa_erw_v  if (mig_v!=.)

* Mutter lebt nicht im HH (isme=1 := ef349=8)
gen migm=migme           if (isme==1)
gen sa1m=sa1me           if (isme==1)
gen sa2m=sa2me           if (isme==1)
gen sa3m=sa3me           if (isme==1)
gen jzuzugm=jzuzugme     if (isme==1)  // 06.11.2012 ex: gen mzuzugm=jzuzugme     if (isme==1)
gen sam=same             if (isme==1)
replace sa_erwm=sa_erwme if (isme==1)

* Gueltige Angaben zu der im HH lebenden Mutter
replace migm=mig_m        if (mig_m!=.)
replace sa1m=sa1_m        if (mig_m!=.)
replace sa2m=sa2_m        if (mig_m!=.)
replace sa3m=sa3_m        if (mig_m!=.)
replace jzuzugm=jzuzug_m  if (mig_m!=.)
replace sam=sa_m          if (mig_m!=.)
replace sa_erwm=sa_erw_m  if (mig_m!=.)

* Vorbereitung MERGE mit Konversionstabelle (conversion.dta)
gen _mig_  = mig3  if (konvproc==1) // MIG-Status vor Konversion
gen _migv_ = migv  if (konvproc==1) // MIG-Status Vater
gen _migm_ = migm  if (konvproc==1) // MIG-Status Mutter
recode _migv_ (0 .=99) (22 23=21) if (konvproc==1)
recode _migm_ (0 .=99) (22 23=21) if (konvproc==1)
format _mig_ _migv_ _migm_ %2.0f

* Sortierung fuer Konversionsprozedur
sort _mig_ _migv_ _migm_ konvproc // 06.11.2012 ex: sort _mig_ _migv_ _migm konvproc

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 v5

* Uebernahme konvertierter MIG-Typisierung
gen mig4 = migneu if (migneu!=.)
replace mig4 = mig3 if (migneu==.)

label var mig4 "Migrationsstatus nach Endtypisierung Befragte"
format mig4 %2.0f
* tab mig4

* Migrationsstatus nicht zeitreihenkompatibel
gen mig2009 = mig4
label var mig2009 "Migrationsstatus 2009 nach Endtypisierung Befragte - jahrgangsspezifisch"
format mig2009 %2.0f
tab mig2009, miss


* SUF Value Labels & Vergroeberung
label def mig4 ///
   0 "Deutsch ohne Migrationshintergrund" ///
  11 "Bis einschliesslich 1949 als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert" ///
  21 "21/29: 1950 und spaeter als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert(Spaetaussiedler) (21); (Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr (29)" ///
  22 "Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist" ///
  25 "Spaetaussiedler mit formaler Einbuergerung" ///
  29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
  31 "Als Auslaender auf das heutige Bundesgebiet zugewandert und zwischenzeitlich eingebuergert" ///
  32 "Als Auslaender im heutigen Bundesgebiet geboren und zwischenzeitlich eingebuergert" ///
  41 "Als Auslaender auf das heutige Bundesgebiet zuwandert" ///
  42 "Als Auslaender im heutigen Bundesgebiet geboren, entweder beide Eltern als Auslaender zugewandert oder der eine Elternteil" ///
  43 "Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren" ///
  52 "Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  53 "Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  54 "Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  62 "Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  63 "Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  64 "Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt" ///
  77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" 
* format mig4 mig2009 mig migv migm %2.0f
label val mig4 mig4
label val mig2009 mig4



/* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag 
        ergaenzen, sofern noetig und moeglich 
        SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern */
gen sa_erw0 = sa_erw
replace sa_erw=sa_erwv if (konvproc==1) & ( (sa_erw==0 | sa_erw==99) & (sa_erwv>0 & sa_erwv<99) ) 
replace sa_erw=sa_erwm if (konvproc==1) & ( (sa_erw==0 | sa_erw==99) & (sa_erwm>0 & sa_erwm<99) )

* Kontrolle
* tab sa_erw, miss

gen migs2009 = sa_erw
* MIGS2009 (ex SA_erw) fuer einheimische Bevoelkerung auf Entfaellt setzen => SUF MZ 2009 EF2008: -5
replace migs2009 = -5 if (mig2009==0 | mig2009==11)
replace migs2009 = -5 if migs2009==0
label var migs2009 "Erweiterte Staatsangehoerigkeit zu MIG2009 - jahrgangsspezifisch"
format migs2009 %2.0f
* tab migs2009, miss

* Zwischenspeicherung
save "temp_MIG4.dta", replace


* Veraenderungen Migrationsstatus bei Endtypisierung Befragte 
* tab mig4 mig3 if (mig4!=mig3), miss nolab

* Veraenderungen erweiterte Staatsangeh. bei Endtypisierung Befragte
* tab sa_erw sa_erw0 if (sa_erw!=sa_erw0), miss nolab

/* =====================================================================
6. Umsetzung von Zeitreihenkompatibilitaet                           .
   In den Jahren 2005 und 2009 laesst sich aufgrund der Zusatzangaben
   zum Migrationsstatus der nicht im Haushalt lebenden Eltern der
   Migrationshintergrund von mehr Menschen erkennen als in den anderen
   Jahren. Das schraenkt die Zeitreihenanalyse ein.
   Deshalb wird nachstehend der Migrationsstatus der Menschen in 2005/
   2009 simuliert, der sich ergeben haette, wenn lediglich die Angaben
   aus den anderen Jahren zur Verfuegung gestanden haetten.
   Betroffen sind lediglich die Deutschen mit einseitigen und
   beidseitigem Migrationshintergrund Codes 61 bzw. 62-64
   Es gelten folgende Regeln:
Einseitiger MigH: Angaben zum bestimmenden Elternteil fehlen:
   Code: 52 -> 72
   Code: 53 -> 73
   Code: 54 -> 74
Beidseitiger MigH: Angaben zu einem bestimmenden Elternteil fehlen:
   Code: 62 -> 57
   Code: 63 -> 58
   Code: 64 -> 59
Beidseitiger MigH: Angaben zu beiden bestimmenden Elternteilen fehlen
   Code: 62 -> 77
   Code: 63 -> 78
   Code: 64 -> 79
(...)


-----------------------------------------------------------------------
Die Variablen xxxV werden aus den entspechenden Angaben von
xxxVE und xxxVI bestimmt. Wenn ISVE=1 (Es liegen Angaben zum Vater ausserhalb
des Haushaltes vor) gelten die Werte von xxxVE, ansonsten die von xxxVI.
Werden jedoch Angaben zum Vater ausserhalb des Haushalts gemacht, obwohl dieser 
im Haushalt lebt, dann ueberschreiben die Angaben des Haushaltsmitglieds die
externen Angaben.
Vorgehensweise bei xxxM entsprechend.

ALTERNATIVE RECODIERUNG zu SAS-Originalprogramm
Zur Umsetzung der zeitreihenkompatiblen MIG - Variable 
werden folgende Variablen verwendet:

MIG4  Migrationsstatus vor Zeitreihenkompatibilitaet
PI    Interne Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter
PE    Externe Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter
IsVE  Vater lebt im Haushalt:  0=ja, 1=nein (EF357=8) : Ext. Ang. Vater
IsME  Mutter lebt im Haushalt: 0=ja, 1=nein (EF357=8) : Ext. Ang. Mutter
MIGMI Migrationsstatus Mutter: interne Angaben
MIGVI Migrationsstatus Vater:  interne Angaben
-------------------------------------------------------------------- */

gen migvi = mig_v // interne Angaben fuer Vater
gen migmi = mig_m // interne Angaben fuer Muetter
format migvi migmi %2.0f
*       Hilfsvariablen (SYSMIS => -1)
recode migmi migvi (.=-1), gen(xmigmi xmigvi) copyrest

gen mig = mig4
label var mig "Migrationsstatus zeitreihenkompatibel [~EF2001~]"


gen migs = sa_erw
label var migs "Erweiterte Staatsangehoerigkeit zu MIG zeitreihenkmpatibel [~EF2008~]"
format xmigmi xmigvi mig migs %2.0f

* Fall 1: Beidseitiger MigH der Person (mig4>=62 & mig4<=64)
*         Angaben zu beiden bestimmenden Elternteilen fehlen (PI=1)
replace mig  = mig4 + 15 if ((mig4>=62 & mig4<=64) & (pi==1))
replace migs = 99        if ((mig4>=62 & mig4<=64) & (pi==1))

* Fall 2: Interne Angaben fuer Mutter vorhanden (PI=4)
*         ... dann einseitiger Migrationshintergrund
replace mig  = 58 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=0  & xmigmi<=77))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=0  & xmigmi<=77))
replace mig  = 57 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=21 & xmigmi<=29))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=21 & xmigmi<=29))
replace mig  = 59 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=41 & xmigmi<=43))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=41 & xmigmi<=43))

* Fall 3: Interne Angaben fuer Vater vorhanden (PI=3) und 
*         keine internen Angaben fuer Mutter vorhanden 
*         ... dann einseitiger Migrationshintergrund 
replace mig  = 58 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=0  & xmigvi<=77))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=0  & xmigvi<=77))
replace mig  = 57 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=21 & xmigvi<=29))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=21 & xmigvi<=29))
replace mig  = 59 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=41 & xmigvi<=43))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=41 & xmigvi<=43))

* Fall 4: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54)
*         Externe Angaben zum Vater (ISVE=1) ohne
*         interne Angaben zum Vater (EF55<1) ... dann Code 52-54 -> 72-74
replace mig  = mig4 + 20 if ( (mig4>=52 & mig4<=54) & isve==1 & ef55<1 & ///
         (migv==21 | migv==22 | migv==23 | migv==25 | migv==29 | migv==31 | ///
	  migv==32 | migv==33 | migv==41 | migv==42 | migv==43 | migv==61 | ///
	  migv==62 | migv==63 | migv==64) )
replace migs = 99  if ( (mig4>=52 & mig4<=54) & isve==1 & ef55<1 & ///
         (migv==21 | migv==22 | migv==23 | migv==25 | migv==29 | migv==31 | ///
	  migv==32 | migv==33 | migv==41 | migv==42 | migv==43 | migv==61 | ///
	  migv==62 | migv==63 | migv==64) )

* Fall 5: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54)
*         Externe Angaben zur Mutter (ISME=1) ohne
*         interne Angaben zur Mutter (EF53<1)... dann Code 52-54 -> 72-74
replace mig = mig4 + 20 if ( (mig4>=52 & mig4<=54) & isme==1 & ef53<1 & ///
         (migm==21 | migm==22 | migm==23 | migm==25 | migm==29 | migm==31 | ///
	  migm==32 | migm==33 | migm==41 | migm==42 | migm==43 | migm==61 | ///
	  migm==62 | migm==63 | migm==64) )
replace migs = 99 if ( (mig4>=52 & mig4<=54) & isme==1 & ef53<1 & ///
         (migm==21 | migm==22 | migm==23 | migm==25 | migm==29 | migm==31 | ///
	  migm==32 | migm==33 | migm==41 | migm==42 | migm==43 | migm==61 | ///
	  migm==62 | migm==63 | migm==64) )

* Vergroeberungen, Rekodierungen MIGS wie EF2008 im SUF MZ 2009
* MIGS (ex SA_erw) fuer einheimische Bevoelkerung auf Entfaellt setzen => SUF MZ 2009 EF2008: -5
replace migs = -5 if migs==0 // sa_erw==0
replace migs = -5 if (mig==0 | mig==11)


label def mig ///
   0 "Deutsch ohne Migrationshintergrund" ///
  11 "Bis einschl. 1949 als Deutscher ohne Einbuergerung zugewandert" ///
  21 "21/29: >=1950 als Deutscher ohne Einbuergerung zugewandert (Spaetaussiedler)(21); Ohne Angabe des Zuzugsjahres als Deutscher ohne Einbuergerung zugewandert(29)" ///
  22 "Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist" ///
  25 "Spaetaussiedler mit formaler Einbuergerung" ///
  29 "Ohne Angabe des Zuzugsjahres als Deutscher ohne Einbuergerung zugewandert" ///
  31 "Als Auslaender zugewandert und zwischenzeitlich eingebuergert" ///
  32 "Als Auslaender im Bundesgebiet geboren und zwischenzeitlich eingebuergert" ///
  41 "Als Auslaender auf das heutige Bundesgebiet zuwandert" ///
  42 "Als Auslaender im Bundesgebiet geboren, beide Eltern als Auslaender zugewandert oder ein Elternteil als Auslaender zugewandert, der andere als Auslaender im Bundesgebiet geboren" ///
  43 "Als Auslaender im Bundesgeb. geboren, beide Eltern im Bundesgeb. geboren" ///
  52 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil Eltern im Haushalt; 1 Elternteil Spaetaussiedler (21,22,25,29)" ///
  53 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil mit Eltern im Haushalt; 1 Elternteil Deutscher durch Einbuerg. (31,32)" ///
  54 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil mit Eltern im Haushalt; 1 Elternteil ist Auslaender (41,42,43)" ///
  57 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil nur mit 1 Elternteil im Haushalt; dieser Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  58 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil im Haushalt; dieser Elternteil ist eingebuergert (31,32)" ///
  59 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil im Haushalt; dieser Elternteil ist Auslaender (41,42,43)" ///
  62 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt lebend; mind. 1 Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  63 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt; entweder beide Eltern eingeb. (31,32) oder 1 Elternteil eingebuergert (31,32), der andere Auslaender (41,42,43)" ///
  64 "Deutscher mit beids. Mig.hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt; beide Eltern sind Auslaender (41,42,43), es handelt sich um ein ius soli-Kind (Optionsmodell)" ///
  72 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Mig-status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Spaetaussiedler (21,22,25,29) f. d. Mig-status bestimmend" ///
  73 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Deutscher durch Einbuergerung (31,32) fuer Status bestimmend ist" ///
  74 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Auslaender (41,42,43) fuer den Status bestimmend ist" ///
  77 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; mindestens ein Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  78 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; entweder beide Eltern eingebuergert (31,32) oder 1 Elternteil eingebuergert (31,32), der andere Auslaender (41,42,43)" ///
  79 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; beide Eltern sind Auslaender (41,42,43); ius soli-Kind (Optionsmodell)" 
label val mig mig
numlabel mig, add mask("[#] ") force

/* ============================================================================
ZU BEACHTEN: MIGS stimmt nicht vollstaendig mit EF2008 ueberein, da die
Codierungen der Angaben zu den Staatsangehoerigkeiten der Eltern ausserhalb
des Haushalts:
- EF353  F105a 1. ausl. Staatsangehoerigk.: Mutter
- EF361  F111a 1. ausl. Staatsangehoerigk.: Vater
von den Angaben zur Person:
- EF369  F99a 1. Staatsangehoerigkeit
abweichen und die Codierungen von EF369 und EF2008 verschieden sind.
============================================================================ */


****************************
* ENDE DER MIG-TYPISIERUNG *
****************************

* Kontrolle MIG = EF2001 ?
tab ef2001 mig if (ef2001!=mig)
* OK: keine Differenzen bis auf EF2001=43 <=> MIG=42: n = 266
*     Grund: neue Konversionstabelle (conversion_2011.xls => conversion.sav)

* Kontrolle MIGS = EF2008 ?
count if (ef2008!=migs)
* 3.324 Differenzen; Grund: unterschiedliche Codierungen (s. o.)


* =====================================================================

* Randverteilungen, ohne Selektion, ohne Hochrechnung
tab1 mig mig2009

* Bevoelkerung am Hauptwohnsitz, Hochrechnung (Jahresdurchschnitt)
tab mig     if ef30<3 [iw=ef952], miss
tab mig2009 if ef30<3 [iw=ef952], miss

* =====================================================================

/* 
7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse 

MZ-GRUNDPROGRAMM: Migrationsstatus 
Fachserie 1, Reihe 2.2, Tabelle 2, S. 60
Definition Z* entspricht Lfd. Nr. in Tab. 2 */
recode mig  (0/79=1) (*=.), gen(Z001)
recode mig  (0 11=1) (*=.), gen(Z002)
recode mig  (0 11 72/79=1) (*=.), gen(Z002x)
recode mig  (21/79=1) (*=.), gen(Z003)
recode mig  (72/79=1) (*=.), gen(Z004)
recode mig  (21/64=1) (*=.), gen(Z005)
recode mig  (21 22 25 29 31 41=1) (*=.), gen(Z036)
recode mig  (41=1) (*=.), gen(Z066)
recode mig  (21 22 25 29 31=1) (*=.), gen(Z095)
recode mig  (21 22 25 29=1) (*=.), gen(Z096)
recode mig  (31=1) (*=.), gen(Z109)
recode mig  (32 42 43 52/64=1) (*=.), gen(Z133)
recode mig  (42 43 =1) (*=.), gen(Z140)
recode mig  (32 52/64=1) (*=.), gen(Z147)
recode mig  (32=1) (*=.), gen(Z148)
recode mig  (52/64=1 ) (*=.), gen(Z154)
recode mig  (62 63 64=1 ) (*=.), gen(Z155)
recode mig  (52/59=1 ) (*=.), gen(Z156)
label var Z001  "Bevoelkerung insgesamt [0-79]'
label var Z002  "Person ohne Migrationshintergrund [0,11]"
label var Z002x "Ohne Mig-hintergrund [i.e.S.] [0,11,72-79]"
label var Z003  "Person mit Mig-hintergrund i. w. S. [21-79]"
label var Z004  " darunter: Mig-hintergrund nicht durchgaengig bestimmbar [72-79]"
label var Z005  "Personen mit Mig-hintergrund im engeren Sinn [21-64]"
label var Z036  "Personen mit Mig-hintergrund und eigener Migrationserfahrung [21-29,31,41]"
label var Z066  " Auslaender [41]"
label var Z095  " Deutsche [21-31]"
label var Z096  " (Spaet-) Aussiedler [21-29]"
label var Z109  " durch Einbuegerung [31]"
label var Z133  "Personen ohne eigene Mig-erfahrung [32,42-43,52-64]"
label var Z140  " Auslaender [42-43]"
label var Z147  " Deutsche [32,52-64]"
label var Z148  " durch Einbuergerung [32]"
label var Z154  "mit mind. 1 zugewanderten oder als Auslaender in D geb. Elternteil [52-64]"
label var Z155  " mit beidseitigem Mig-hintergrund [62-64]"
label var Z156  " mit einseitigem Mig-hintergrund [52-59]"


/* MIGRATIONSSTATUS
Vergleich mit Tabelle 2, S. 60 in: Statistisches Bundesamt, 2011:
Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, Reihe 2.2 
Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 2009. 
Wiesbaden */
summ Z001-Z156 if (ef30<3) [iw=ef952], sep(0)


/* ===================================================================
STAATSANGEHOERIGKEITEN Vergleich mit Tab. 2 Fachserie 1, Reihe 2.2
Recodierung Erw. Staatsangeh. (EF2008): 
   Deutsche 
   bis einschl. 1949 als D zugewandert, 
   Deutsche Zuwanderer ohne Einbuergerung,
   in DE geborene D mit ein-/beids. Mig-hintergund
=> 0 (deutsch)  */
generate migs_r = ef2008
replace  migs_r = 0 if mig<20  /* aequivalent: ef2001<20 ... */
replace  migs_r = 0 if mig>60
label var migs_r "Staatsangeh.: erw. Migrationsstatus - EF2008 recodiert"
format migs_r %2.0f


* Z:= Lfd.Nr. in Tab. 2, Fachserie 1 R 2.2 // 
recode migs_r (1/6 9 10 13 14 21/26 28 31/36 56 58 91 92 96=1) (*=.), gen(Z06) // Europa
recode migs_r (1 3 4 9 10 13 21/25 31/33 35 36=1) (*=.), gen(Z07) // EU-27
recode migs_r (10=1) (*=.), gen(Z08) // Griechenland
recode migs_r (13=1) (*=.), gen(Z09) // Italien
recode migs_r (23=1) (*=.), gen(Z10) // Polen
recode migs_r (25=1) (*=.), gen(Z11) // Rumaenien
recode migs_r (2 5 6 14 26 28 34 56 58 91 92 96=1) (*=.), gen(Z12) // Sonstiges Europa
recode migs_r (2=1) (*=.), gen(Z13)  // Bosnien-Herzegowina
recode migs_r (14=1) (*=.), gen(Z14) // Kroatien
recode migs_r (26=1) (*=.), gen(Z15) // Russische Foederation
* recode migs_r (58=1) (*=.), gen(Z16) // 58: Serbien(58) & Montenegro(59)
recode migs_r (34=1) (*=.), gen(Z17) // Tuerkei
recode migs_r (56=1) (*=.), gen(Z18) // Ukraine 
recode migs_r (40/42=1) (*=.), gen(Z19) // Afrika
recode migs_r (43/46=1) (*=.), gen(Z20) // Amerika
recode migs_r (47/54 57 94 95=1) (*=.), gen(Z22) // Asien, Australien und Ozeanien
recode migs_r (47/49 57 94 95=1) (*=.), gen(Z23) // Naher und Mittlerer Osten 
recode migs_r (57=1) (*=.), gen(Z24) // Kasachstan
recode migs_r (50/52=1) (*=.), gen(Z25) // Sued- Suedostasien
recode migs_r (-5 0 55 98 99=1) (*=.), gen(Z26) // Ohne Angabe bzw. unzutreffend
recode migs_r (2 6 14 58 59 91 92=1) (*=.), gen(Z27) // Gebiet des ehemaligen Jugoslawien
recode migs_r (5 7 15 17 26 56 57 90 93/95=1) (*=.), gen(Z28) // Gebiet der ehemaligen Sowjetunion
label var Z06 "Europa"
label var Z07 "EU-27"
label var Z08 "Griechenland"
label var Z09 "Italien"
label var Z10 "Polen"
label var Z11 "Rumaenien"
label var Z12 "Sonstiges Europa"
label var Z13 "Bosnien-Herzegowina"
label var Z14 "Kroatien"
label var Z15 "Russische Foederation"
* label var Z16 "Serbien(58) & Montenegro(59)"
label var Z17 "Tuerkei"
label var Z18 "Ukraine "
label var Z19 "Afrika"
label var Z20 "Amerika"
label var Z22 "Asien, Australien und Ozeanien"
label var Z23 "Naher und Mittlerer Osten "
label var Z24 "Kasachstan"
label var Z25 "Sued- Suedostasien"
label var Z26 "Ohne Angabe bzw. unzutreffend"
label var Z27 "Gebiet des ehemaligen Jugoslawien"
label var Z28 "Gebiet der ehemaligen Sowjetunion"
summ Z005 Z06-Z28 if (ef30<3 & mig>=21 & mig<=64) [iw=ef952], sep(0)



* Hilfsvariablen loeschen
drop xmigmi xmigvi

/* Sortierung nach Ordnungsnummern fuer Zuspielen der erstellten 
   Variablen MIG und MIG2009 zum Scientific Use File */
sort ef1 ef3 ef4 ef5b ef12 ef5a


* Zwischenspeicherung 
save "temp_mig5.dta", replace


exit

* ################################################################################
* PROGRAMMENDE


